pub enum SendRawEmailError {
AccountSendingPaused(String),
ConfigurationSetDoesNotExist(String),
ConfigurationSetSendingPaused(String),
MailFromDomainNotVerified(String),
MessageRejected(String),
}Expand description
Errors returned by SendRawEmail
Variants
AccountSendingPaused(String)
Indicates that email sending is disabled for your entire Amazon SES account.
You can enable or disable email sending for your Amazon SES account using UpdateAccountSendingEnabled.
ConfigurationSetDoesNotExist(String)
Indicates that the configuration set does not exist.
ConfigurationSetSendingPaused(String)
Indicates that email sending is disabled for the configuration set.
You can enable or disable email sending for a configuration set using UpdateConfigurationSetSendingEnabled.
MailFromDomainNotVerified(String)
Indicates that the message could not be sent because Amazon SES could not read the MX record required to use the specified MAIL FROM domain. For information about editing the custom MAIL FROM domain settings for an identity, see the Amazon SES Developer Guide.
MessageRejected(String)
Indicates that the action failed, and the message could not be sent. Check the error stack for more information about what caused the error.
Implementations
Sourceimpl SendRawEmailError
impl SendRawEmailError
pub fn from_response( res: BufferedHttpResponse, ) -> RusotoError<SendRawEmailError>