pub enum UpdateConfigurationSetTrackingOptionsError {
ConfigurationSetDoesNotExist(String),
InvalidTrackingOptions(String),
TrackingOptionsDoesNotExist(String),
}Expand description
Errors returned by UpdateConfigurationSetTrackingOptions
Variants
ConfigurationSetDoesNotExist(String)
Indicates that the configuration set does not exist.
InvalidTrackingOptions(String)
Indicates that the custom domain to be used for open and click tracking redirects is invalid. This error appears most often in the following situations:
-
When the tracking domain you specified is not verified in Amazon SES.
-
When the tracking domain you specified is not a valid domain or subdomain.
TrackingOptionsDoesNotExist(String)
Indicates that the TrackingOptions object you specified does not exist.
Implementations